==> ws-v3.70.8-src.tar.gz: ws-v3.70-8/include/WSCvendbtn.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCVFBTN_H
#define WSCVFBTN_H

#include <WScom.h>
#include <WSCvbtn.h>
class WSDkeyboard;
#define WSCvendbtn_VER  1000

class WSCvendbtn   :public WSCvbtn{

  protected:
    WSCuchar  _indicator_size;
    unsigned   _exit:1;

    WSMFpropertyDef(WSNindicatorSize,   WSCuchar, _indicator_size   );
    WSMFpropertyDef(WSNexit,   WSCbool,  _exit    );

  public:
    WSCvendbtn(WSCbase* base, char* name);
    virtual ~WSCvendbtn();

    virtual long draw();
    virtual void onActivate();

    WSMFguiClassDef(WSCvendbtn,WSCvbtn);
    WSMFversionDef(WSCvendbtn);
};
#endif

==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/WSCvendbtn.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef WSCVFBTN_H
#define WSCVFBTN_H

#include <WScom.h>
#include <WSCvbtn.h>
class WSDkeyboard;
#define WSCvendbtn_VER  1000

class WSCvendbtn   :public WSCvbtn{

  protected:
    WSCuchar  _indicator_size;
    unsigned   _exit:1;

    WSMFpropertyDef(WSNindicatorSize,   WSCuchar, _indicator_size   );
    WSMFpropertyDef(WSNexit,   WSCbool,  _exit    );

  public:
    WSDLEX32 WSCvendbtn(WSCbase* base, char* name);
    WSDLEX32 virtual ~WSCvendbtn();

    WSDLEX32 virtual long draw();
    WSDLEX32 virtual void onActivate();

    WSMFguiClassDef(WSCvendbtn,WSCvbtn);
    WSMFversionDef(WSCvendbtn);
};
#endif
